@@ -23,6 +23,7 @@ from apscheduler.util import ref_to_obj
 from flask_apscheduler.views import get_job
 from flask_apscheduler.views import get_jobs
 from flask_apscheduler.views import run_job
+from flask_apscheduler.views import get_scheduler_info
 
 LOGGER = logging.getLogger(__name__)
 
@@ -46,6 +47,10 @@ class APScheduler(object):
     def allowed_hosts(self):
         return self.__allowed_hosts
 
+    @property
+    def running(self):
+        return self.scheduler.running
+
     @property
     def scheduler(self):
         return self.__scheduler
@@ -59,12 +64,6 @@ class APScheduler(object):
         self.__load_config(app)
         self.__load_views(app)
 
-    def get_job(self, job_id):
-        return self.__scheduler.get_job(job_id)
-
-    def get_jobs(self):
-        return self.__scheduler.get_jobs()
-
     def start(self):
         if not self.allowed_hosts:
             LOGGER.debug('None server allowed to start the scheduler.')
@@ -82,33 +81,35 @@ class APScheduler(object):
     def __load_config(self, app):
         options = dict()
 
-        job_stores = app.config.get('APSCHEDULER_JOBSTORES')
+        job_stores = app.config.get('SCHEDULER_JOBSTORES')
         if job_stores:
             options['jobstores'] = job_stores
 
-        executors = app.config.get('APSCHEDULER_EXECUTORS')
+        executors = app.config.get('SCHEDULER_EXECUTORS')
         if executors:
             options['executors'] = executors
 
-        job_defaults = app.config.get('APSCHEDULER_JOB_DEFAULTS')
+        job_defaults = app.config.get('SCHEDULER_JOB_DEFAULTS')
         if job_defaults:
             options['job_defaults'] = job_defaults
 
-        timezone = app.config.get('APSCHEDULER_TIMEZONE')
+        timezone = app.config.get('SCHEDULER_TIMEZONE')
         if timezone:
             options['timezone'] = timezone
 
         self.__scheduler.configure(**options)
 
-        jobs = app.config.get('APSCHEDULER_JOBS')
+        jobs = app.config.get('SCHEDULER_JOBS')
+
+        if jobs is None:
+            jobs = app.config.get('JOBS')
 
         for job in jobs:
             self.__load_job(app, job)
 
-        hosts = app.config.get('APSCHEDULER_ALLOWED_HOSTS')
+        hosts = app.config.get('SCHEDULER_ALLOWED_HOSTS')
         if hosts:
-            for host in hosts:
-                self.__allowed_hosts.append(host.lower())
+            self.__allowed_hosts = hosts
 
     def __load_job(self, app, job):
         def call_func(*args, **kwargs):
@@ -130,44 +131,14 @@ class APScheduler(object):
         func_args = job.get('args')
         func_kwargs = job.get('kwargs')
 
-        trigger_args = dict()
-        trigger_type = trigger.get('type')
+        trigger_type = trigger.pop('type')
 
-        if trigger_type == 'interval':
-            self.__copy_item('weeks', trigger, trigger_args)
-            self.__copy_item('days', trigger, trigger_args)
-            self.__copy_item('hours', trigger, trigger_args)
-            self.__copy_item('minutes', trigger, trigger_args)
-            self.__copy_item('seconds', trigger, trigger_args)
-            self.__copy_item('start_date', trigger, trigger_args)
-            self.__copy_item('end_date', trigger, trigger_args)
-            self.__copy_item('timezone', trigger, trigger_args)
-        elif trigger_type == 'cron':
-            self.__copy_item('year', trigger, trigger_args)
-            self.__copy_item('month', trigger, trigger_args)
-            self.__copy_item('day', trigger, trigger_args)
-            self.__copy_item('week', trigger, trigger_args)
-            self.__copy_item('day_of_week', trigger, trigger_args)
-            self.__copy_item('hour', trigger, trigger_args)
-            self.__copy_item('minute', trigger, trigger_args)
-            self.__copy_item('second', trigger, trigger_args)
-        elif trigger_type == 'date':
-            self.__copy_item('run_date', trigger, trigger_args)
-            self.__copy_item('timezone', trigger, trigger_args)
-        else:
-            raise Exception('Trigger %s is invalid.' % trigger)
-
-        job = self.__scheduler.add_job(call_func, trigger_type, func_args, func_kwargs, id, **trigger_args)
+        job = self.__scheduler.add_job(call_func, trigger_type, func_args, func_kwargs, id, **trigger)
         job.func_ref = func_ref
 
     @staticmethod
     def __load_views(app):
-        app.add_url_rule('/jobs', 'get_jobs', get_jobs)
-        app.add_url_rule('/jobs/<job_id>', 'get_job', get_job)
-        app.add_url_rule('/jobs/<job_id>/run', 'run_job', run_job)
-
-    @staticmethod
-    def __copy_item(prop, src, dst):
-        value = src.get(prop)
-        if value:
-            dst[prop] = value
+        app.add_url_rule('/scheduler', 'get_scheduler_info', get_scheduler_info)
+        app.add_url_rule('/scheduler/jobs', 'get_jobs', get_jobs)
+        app.add_url_rule('/scheduler/jobs/<job_id>', 'get_job', get_job)
+        app.add_url_rule('/scheduler/jobs/<job_id>/run', 'run_job', run_job)
